%NOTE this example tries to load matlab .mat file
%      "randmat.mat" from disk. Since this is a large
%      file it's not part of the examples. Before using 
%      this example script you can create you own sample
%      data file using the following commands:
%
%      data=rand(50000,2500);
%      save randmat data
%
%      The file "randmat.mat" is about 900M. You can change the 
%      dimensions if needed
%      to run it you will first need to open a matlabpool
%      For help, please send email to help@sc.tamu.edu

spmd 
    
    % every worker will load 'randmat.mat' from disk and assigns it
    % to matlab struct dstruct. Unlike on the client, you cannot load
    % data directly into the workspace, you have to assign it to a struct
    % first
    dstruct = load('randmat','data');
    data = dstruct.data;
    ddim=size(data);
    
    % cannot assume 'data' on other workers has same dimension
    % so need to find out dimension of 'data' on other workers
    % in this example we assume first dimension (i.e. #rows)
    % is the same on every worker
    distsize= codistributed(zeros(1,numlabs));
    distsize(labindex)=ddim(2);

    % this will be the partitioning scheme, all workers have the same
    % value for dg
    dg=gather(distsize);
    
    %this will be the dimensions of the distributed array
    totr = ddim(1);
    totc = sum(dg);
    
    % the codistributor object
    % we will distributed over the second dimension, partitioning 
    % scheme is dg, and the dimensions of the total distributed array
    % is [totr totc]
    cod = codistributor1d(2,dg,[totr totc]);
    
    % finally create the codistributed array using the build function
    ddata=codistributed.build(data,cod); 
    
    % Now we can perform operations on the array as if it was local. e.g.
    % ddata = ddata * 2.1
    
end
