% basic monte carlo method to compute pi
% The circle/box area ratio is always pi/4 (pi* ((1/2)*n)^2) / n^2) = pi/4.
% To estimate pi, pick N random point (and N is large enough) and count the
% number of points inside the circle. pi =  inside*4 /total
%
% In this version we will use a  distributed array. Input 
% variable N is the number of points we will use to compute pi. Large 
% value of N will result in a more accurate approximation of pi

function piresult = compute_pi_distributed(N)
tic;
x=distributed.rand(N,1);
y=distributed.rand(N,1);
total_inside= sum(((x .* x + y .* y) < 1)); 
piresult = 4*total_inside/N;
toc
fprintf('The computed value of pi is %8.7f.\n',gather(piresult));
end
