% basic monte carlo method to compute pi
% The circle/box area ratio is always pi/4 (pi* ((1/2)*n)^2) / n^2) = pi/4.
% To estimate pi, pick N random point (and N is large enough) and count the
% number of points inside the circle. pi =  inside*4 /total
%
% In this version we will use a  distributed array and spmd block. Input 
% variable N is the number of points we will use to compute pi. Large 
% value of N will result in a more accurate approximation of pi

function piresult = compute_pi_distributed_spmd(N)
tic;
x=distributed.rand(N,1);
y=distributed.rand(N,1);

% compute partial sums on the workers
spmd
   localx = getLocalPart(x);
   localy = getLocalPart(y);

   total_inside=sum((localx .^2 + localy .^2) < 1);
end

% combine the results of the workers
numworkers = length(total_inside);
total = 0;
for i=1:numworkers
    total=total+total_inside{i};
end
piresult = 4*total/N;
toc
fprintf('The computed value of pi is %8.7f.\n',gather(piresult));
end
