% basic monte carlo method to compute pi
% The circle/box area ratio is always pi/4 (pi* ((1/2)*n)^2) / n^2) = pi/4.
% To estimate pi, pick N random point (and N is large enough) and count the
% number of points inside the circle. pi =  inside*4 /total
%
% In this version we will use a spmd block. Input variable N is the number
% of points we will use to compute pi. Large value of N will result in
% a more accurate approximations of pi

function piresult = compute_pi_spmd(N)
tic;
spmd
    NS = N/numlabs;
    xcoord=rand(NS,1);
    ycoord=rand(NS,1);
    tc=0;
    for i=1:NS
        if (xcoord(i)^2 + ycoord(i)^2 <= 1)
            tc=tc+1;
        end
    end
end

global_inside=0;
for i=1:length(tc)
    global_inside = global_inside+tc{i};
end
piresult = 4*global_inside/N;
toc
fprintf('The computed value of pi is %8.7f.\n',piresult);
end
